.. _signal_analysis.higuchi:

Higuchi Fractal Dimension
=========================

.. automodule:: eyetrace.signal_analysis.higuchi
   :members:
   :undoc-members:
   :show-inheritance:

Higuchi’s algorithm estimates the fractal dimension of a time series, which
characterizes its roughness or self‑similarity. Values typically lie between
1 (smooth, deterministic) and 2 (highly irregular, like white noise).